/***************************************************************************
 *   Copyright (C) 2009 by Guy Rutenberg <guyrutenberg@gmail.com>	   *
 *                                                                         *
 *   This is free software; you can redistribute it and/or modify          *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef ABSTRACT_AI_ENGINE_INC
#define ABSTRACT_AI_ENGINE_INC

class AbstractAiEngine
{
public:
	/**
	 * Get the number of seeds in scoring-house i (0..1).
	 */
	virtual int scoringHouse(int i) = 0;

	/**
	 * Get the number of seeds in house i (0..11)
	 */
	virtual int house(int i) = 0;

	/**
	 * \returns The number of house played from in the last move
	 */
	virtual int lastMove() = 0;

	/**
	 * Sow the seeds from house number i (0..11).
	 * \returns True if the move was legal, false otherwise.
	 */
	virtual bool makeMove(int i) = 0;

	/**
	 * Use the AI to make the next move.
	 * \returns A heuristic evaluation of how good the move was. It's
	 * meant for debug purpose only, and isn't compatible between
	 * different engines.
	 */
	virtual int makeAiMove() = 0;

	/**
	 * \returns The player number whose turn is to play (0,1)
	 */
	virtual int nextPlayer() = 0;

	/**
	 * \returns True if game is over, false otherwise.
	 */
	virtual bool isGameOver() = 0;

	//virtual ~AbstractAiEngine() = 0;
};

#endif // ABSTRACT_AI_ENGINE_INC
